@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Mapping, Sequence, Union
 
-from botocore.response import StreamingBody
-
 from .literals import (
     EncryptionStatusType,
     ErrorCauseType,
@@ -256,7 +254,7 @@ GetDigestRequestRequestTypeDef = TypedDict(
 GetDigestResponseTypeDef = TypedDict(
     "GetDigestResponseTypeDef",
     {
-        "Digest": StreamingBody,
+        "Digest": bytes,
         "DigestTipAddress": "ValueHolderTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
